@@ -43,12 +43,23 @@ function validname($name) {
 function escape($name) {return escapeshellarg(validname($name));}
 function quoted($name) {return is_array($name) ? implode(' ',array_map('escape',$name)) : escape($name);}
 
-switch ($_POST['mode']) {
+switch ($_POST['mode'] ?? $_GET['mode'] ?? '') {
 case 'upload':
-  $file = validname(htmlspecialchars_decode(rawurldecode($_POST['file'])));
+  $file = validname(rawurldecode($_POST['file'] ?? $_GET['file'] ?? ''));
   if (!$file) die('stop');
+  $start = (int)($_POST['start'] ?? $_GET['start'] ?? 0);
+  $cancel = (int)($_POST['cancel'] ?? $_GET['cancel'] ?? 0);
   $local = "/var/tmp/".basename($file).".tmp";
-  if ($_POST['start']==0) {
+  // Check cancel BEFORE creating new file
+  if ($cancel==1) {
+    if (file_exists($local)) {
+      $file = file_get_contents($local);
+      if ($file !== false) delete_file($file);
+    }
+    delete_file($local);
+    die('stop');
+  }
+  if ($start === 0) {
     $my = pathinfo($file); $n = 0;
     while (file_exists($file)) $file = $my['dirname'].'/'.preg_replace('/ \(\d+\)$/','',$my['filename']).' ('.++$n.')'.($my['extension'] ? '.'.$my['extension'] : '');
     file_put_contents($local,$file);
@@ -58,19 +69,32 @@ case 'upload':
     chown($file,'nobody');
     chmod($file,0666);
   }
-  $targetFile = file_get_contents($local);
-  if ($_POST['cancel']==1) {
-    delete_file($targetFile);
-    die('stop');
+  $file = file_get_contents($local);
+  // Temp file does not exist
+  if ($file === false) {
+    die('error:tempfile');
   }
-  if (file_put_contents($targetFile,base64_decode($_POST['data']),FILE_APPEND)===false) {
-    delete_file($targetFile);
-    die('error');
+  // Support both legacy base64 method and new raw binary method
+  if (isset($_POST['data'])) {
+    // Legacy base64 upload method (backward compatible)
+    $chunk = base64_decode($_POST['data']);
+  } else {
+    // New raw binary upload method (read from request body)
+    $chunk = file_get_contents('php://input');
+    if (strlen($chunk) > 21000000) { // slightly more than 20MB to allow overhead
+      unlink($local);
+      die('error:chunksize:'.strlen($chunk));
+    }
+  }
+  if (file_put_contents($file,$chunk,FILE_APPEND)===false) {
+    delete_file($file);
+    delete_file($local);
+    die('error:write');
   }
   die();
 case 'calc':
   extract(parse_plugin_cfg('dynamix',true));
-  $source = explode("\n",htmlspecialchars_decode(rawurldecode($_POST['source'])));
+  $source = explode("\n",rawurldecode($_POST['source'] ?? ''));
   [$null,$root,$main,$rest] = my_explode('/',$source[0],4);
   if ($root=='mnt' && in_array($main,['user','user0'])) {
     $disks = parse_ini_file('state/disks.ini',true);
@@ -97,8 +121,8 @@ case 'calc':
   $calc   = '<div style="text-align:left;margin-left:56px">'.implode('<br>',$calc).'</div>';
   die($calc);
 case 'home':
-  $source = explode("\n",htmlspecialchars_decode(rawurldecode($_POST['source'])));
-  $target = htmlspecialchars_decode(rawurldecode($_POST['target']));
+  $source = explode("\n",rawurldecode($_POST['source'] ?? ''));
+  $target = rawurldecode($_POST['target'] ?? '');
   $disks = parse_ini_file('state/disks.ini',true);
   $tag  = implode('|',array_merge(['disk'],pools_filter($disks)));
   $loc1 = implode(',',array_unique(array_filter(explode(',',preg_replace("/($tag)/",',$1',exec("getfattr --no-dereference --absolute-names --only-values -n system.LOCATIONS ".quoted($source)." 2>/dev/null"))))));
@@ -129,8 +153,9 @@ case 'save':
   if ($file = validname(rawurldecode($_POST['file']))) file_put_contents($file,rawurldecode($_POST['data']));
   die();
 case 'stop':
-  $file = htmlspecialchars_decode(rawurldecode($_POST['file']));
-  delete_file("/var/tmp/$file.tmp");
+  // Prevent path traversal: only use basename (no directory components)
+  $file = basename(rawurldecode($_POST['file'] ?? ''));
+  if ($file !== '') delete_file("/var/tmp/$file.tmp");
   die();
 case 'start':
   $active = '/var/tmp/file.manager.active';
@@ -140,15 +165,17 @@ case 'start':
     // read first JSON line from jobs file and write to active
     $lines = file($jobs, FILE_IGNORE_NEW_LINES);
     if (!empty($lines)) {
-      // Skip invalid JSON entries (loop until we find valid JSON or run out of entries)
-      while (!empty($lines)) {
-        $data = json_decode($lines[0], true);
-        if ($data) {
-          // Valid JSON found, use it
-          break;
-        }
-        // Invalid JSON, remove this entry and try next
-        array_shift($lines);
+      // Skip invalid JSON entries (scan once, slice once)
+      $skipped = 0;
+      $data = null;
+      for ($i = 0, $n = count($lines); $i < $n; $i++) {
+        $data = json_decode($lines[$i], true);
+        if ($data) break;
+        $skipped++;
+      }
+      if ($skipped > 0) {
+        exec('logger -t webGUI "Warning: Skipped '.$skipped.' invalid JSON entr'.($skipped===1?'y':'ies').' in file manager job queue"');
+        $lines = array_slice($lines, $skipped);
       }
       
       if (empty($lines)) {
@@ -157,6 +184,11 @@ case 'start':
         die('0');
       }
       
+      // Update popular destinations when dequeuing a job
+      if (in_array((int)($data['action'] ?? 0), [3, 4, 8, 9]) && !empty($data['target'] ?? '')) {
+        updatePopularDestinations($data['target']);
+      }
+      
       file_put_contents($active, $lines[0]);
       // remove first line from jobs file
       array_shift($lines);
@@ -174,14 +206,13 @@ case 'undo':
   $jobs = '/var/tmp/file.manager.jobs';
   $undo = '0';
   if (file_exists($jobs)) {
-    $rows = explode(',',$_POST['row']);
+    $rows = explode(',', $_POST['row'] ?? '');
     $lines = file($jobs, FILE_IGNORE_NEW_LINES);
     foreach ($rows as $row) {
-      // Validate and convert to integer to prevent non-numeric input
-      if (!is_numeric($row)) {
-        continue; // Skip invalid entries
-      }
+      $row = trim($row);
+      if ($row === '' || !ctype_digit($row)) continue;
       $row = (int)$row;
+      if ($row < 1) continue;
       $line_number = $row - 1; // Convert 1-based job number to 0-based array index
       if (isset($lines[$line_number])) {
         unset($lines[$line_number]);
@@ -206,8 +237,8 @@ case 'file':
   $data = [
     'action' => (int)($_POST['action'] ?? 0),
     'title' => rawurldecode($_POST['title'] ?? ''),
-    'source' => htmlspecialchars_decode(rawurldecode($_POST['source'] ?? '')),
-    'target' => htmlspecialchars_decode(rawurldecode($_POST['target'] ?? '')),
+    'source' => rawurldecode($_POST['source'] ?? ''),
+    'target' => rawurldecode($_POST['target'] ?? ''),
     'H' => empty($_POST['hdlink']) ? '' : 'H',
     'sparse' => empty($_POST['sparse']) ? '' : '--sparse',
     'exist' => empty($_POST['exist']) ? '--ignore-existing' : '',
@@ -220,12 +251,11 @@ case 'file':
   } else {
     // start operation
     file_put_contents($active, json_encode($data));
-  }
-  
-  // Update popular destinations for copy/move operations
-  // Action types: 3=copy folder, 4=move folder, 8=copy file, 9=move file
-  if (in_array((int)$data['action'], [3, 4, 8, 9]) && !empty($data['target'])) {
-    updatePopularDestinations($data['target']);
+    // Update popular destinations only when an operation actually starts
+    // Action types: 3=copy folder, 4=move folder, 8=copy file, 9=move file
+    if (in_array((int)$data['action'], [3, 4, 8, 9]) && !empty($data['target'])) {
+      updatePopularDestinations($data['target']);
+    }
   }
   
   die();
